@@ -637,7 +637,7 @@ output_watchdog_info_result(PCPResultInfo* pcpResInfo, bool verbose)
 		printf("Remote Nodes         : %d\n",cluster->remoteNodeCount);
 		printf("Quorum state         : %s\n",quorumStatus);
 		printf("Alive Remote Nodes   : %d\n",cluster->aliveNodeCount);
-		printf("VIP up on local node : %s\n",cluster->escalated?"YES":"NO");
+		printf("Local node escalation: %s\n",cluster->escalated ? "YES" : "NO");
 		printf("Master Node Name     : %s\n",cluster->masterNodeName);
 		printf("Master Host Name     : %s\n\n",cluster->masterHostName);
 
